package com.gic.store.service.impl;

import com.gic.commons.util.GlobalInfo;
import com.gic.store.dao.mapper.TabStoreMapper;
import com.gic.store.dto.StoreDTO;
import com.gic.store.entity.TabStore;
import com.gic.store.service.StoreService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * @author zhiwj
 * @date 2019/6/27
 */
@Service
public class StoreServiceImpl implements StoreService {

    @Autowired
    TabStoreMapper tabStoreMapper;

    @Override
    public Integer save(StoreDTO copy) {
        TabStore tabStore = new TabStore();
        tabStore.setStoreId(copy.getStoreId());
        tabStore.setEnterpriseId(copy.getEnterpriseId());
        tabStore.setStoreName(copy.getStoreName());
        tabStore.setStoreCode(copy.getStoreCode());
        tabStore.setRegionId(copy.getRegionId());
        tabStore.setConactsPhone(copy.getConactsPhone());
        tabStore.setAddress(copy.getAddress());
        tabStore.setBrandIds(copy.getBrandIds());
        tabStore.setProvinceId(copy.getProvinceId());
        tabStore.setCityId(copy.getCityId());
        tabStore.setAreaId(copy.getAreaId());
        tabStore.setProvinces(copy.getProvinces());
        tabStore.setLongitude(copy.getLongitude());
        tabStore.setLatitude(copy.getLatitude());
        tabStore.setCompleteStatus(copy.getCompleteStatus());
        // TODO 这里要判断一下总量

        tabStore.setOverflowStatus(0);

        tabStore.setStatus(copy.getStatus());
        tabStore.setErpStatus(copy.getErpStatus());
        tabStore.setStoreType(copy.getStoreType());
        tabStore.setStoreGroupId(copy.getStoreGroupId());
        tabStore.setCreateType(copy.getCreateType());
        tabStore.setCreateTime(new Date());

        tabStoreMapper.insertSelective(tabStore);
        return tabStore.getStoreId();
    }

    @Override
    public Integer update(StoreDTO copy) {
        TabStore tabStore = new TabStore();
        tabStore.setStoreId(copy.getStoreId());
        tabStore.setEnterpriseId(copy.getEnterpriseId());
        tabStore.setStoreName(copy.getStoreName());
        tabStore.setStoreCode(copy.getStoreCode());
        tabStore.setRegionId(copy.getRegionId());
        tabStore.setConactsPhone(copy.getConactsPhone());
        tabStore.setAddress(copy.getAddress());
        tabStore.setBrandIds(copy.getBrandIds());
        tabStore.setProvinceId(copy.getProvinceId());
        tabStore.setCityId(copy.getCityId());
        tabStore.setAreaId(copy.getAreaId());
        tabStore.setProvinces(copy.getProvinces());
        tabStore.setLongitude(copy.getLongitude());
        tabStore.setLatitude(copy.getLatitude());
        tabStore.setStatus(copy.getStatus());
        tabStore.setErpStatus(copy.getErpStatus());
        tabStore.setStoreType(copy.getStoreType());
        tabStore.setStoreGroupId(copy.getStoreGroupId());
        tabStore.setCompleteStatus(copy.getCompleteStatus());

        return tabStoreMapper.updateByPrimaryKeySelective(tabStore);
    }

    @Override
    public Integer countByGroupId(Integer storeGroupId) {
        TabStore tabStore = new TabStore();
        tabStore.setStoreGroupId(storeGroupId);
        return tabStoreMapper.countBySelective(tabStore);
    }

    @Override
    public Integer updateGroupId(Integer oldStoreGroupId, Integer newStoreGroupId) {
        return tabStoreMapper.updateGroupId(oldStoreGroupId, newStoreGroupId);
    }

    @Override
    public TabStore getById(Integer storeId) {
        return tabStoreMapper.selectByPrimaryKey(storeId);
    }

    @Override
    public Integer countByBrandId(Integer brandId) {
        return tabStoreMapper.countByBrandId(brandId);
    }

    @Override
    public Integer countByStoreCode(Integer enterpriseId, String storeCode, Integer storeId) {
        TabStore store = new TabStore();
        store.setEnterpriseId(enterpriseId);
        store.setStoreCode(storeCode);
        store.setStoreId(storeId);
        return tabStoreMapper.countBySelective(store);
    }

    @Override
    public Page listStore(StoreDTO storeDTO, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        return tabStoreMapper.listStore(storeDTO);
    }

    @Override
    public Integer checkCompleteStatus(StoreDTO storeDTO) {
        return StringUtils.isNotBlank(storeDTO.getStoreName()) &&
                storeDTO.getRegionId() != null &&
                StringUtils.isNotBlank(storeDTO.getStoreCode()) &&
                CollectionUtils.isNotEmpty(storeDTO.getPhotoList()) &&
                storeDTO.getStoreType() != null &&
                storeDTO.getErpStatus() != null &&
                StringUtils.isNotBlank(storeDTO.getConactsPhone()) &&
                CollectionUtils.isNotEmpty(storeDTO.getBusinessTimeList()) &&
                storeDTO.getStoreGroupId() != null &&
                StringUtils.isNotBlank(storeDTO.getBrandIds()) &&
                StringUtils.isNotBlank(storeDTO.getProvinces()) &&
                StringUtils.isNotBlank(storeDTO.getLongitude()) &&
                StringUtils.isNotBlank(storeDTO.getLatitude()) &&
                StringUtils.isNotBlank(storeDTO.getAddress())
                ? GlobalInfo.DATA_STATUS_NORMAL
                : GlobalInfo.DATA_STATUS_DELETE
                ;
    }

    @Override
    public List<TabStore> listStoreByRegionAndStatus(List<Integer> regionIdList, List<Integer> statusList) {
        if (CollectionUtils.isEmpty(regionIdList) || CollectionUtils.isEmpty(statusList)) {
            return Collections.emptyList();
        }
        return tabStoreMapper.listStoreByRegionAndStatus(regionIdList, statusList);
    }

    @Override
    public int updateStoreGroupId(Integer storeId, Integer groupId) {
        TabStore store = new TabStore();
        store.setStoreId(storeId);
        store.setStoreGroupId(groupId);
        return tabStoreMapper.updateByPrimaryKeySelective(store);
    }
}
